@@ -1,5 +1,5 @@
 package Test::Mock::Wrapper;
-$Test::Mock::Wrapper::VERSION = '0.15';
+$Test::Mock::Wrapper::VERSION = '0.16';
 use strict;
 use warnings;
 use base qw(Exporter);
@@ -28,7 +28,7 @@ Test::Mock::Wrapper
 
 =head1 VERSION
 
-version 0.15
+version 0.16
 
 =head1 SYNOPSIS
 
@@ -160,7 +160,7 @@ mocked class...  consider the following example:
 	return "fun";
     }
     
-    pacakage Dog;
+    package Dog;
     use base qw(Pet);
     
     sub speak {
@@ -486,7 +486,7 @@ sub resetAll {
 
 
 package Test::Mock::Wrapper::Method;
-$Test::Mock::Wrapper::Method::VERSION = '0.15';
+$Test::Mock::Wrapper::Method::VERSION = '0.16';
 use Test::Deep;
 use strict;
 use warnings;
@@ -522,7 +522,7 @@ sub hasMock {
 }
 
 package Test::Mock::Wrapper::Method::Mock;
-$Test::Mock::Wrapper::Method::Mock::VERSION = '0.15';
+$Test::Mock::Wrapper::Method::Mock::VERSION = '0.16';
 use Test::Deep;
 use strict;
 use warnings;
@@ -588,7 +588,7 @@ sub _fetchReturn {
 
 
 package Test::Mock::Wrapped;
-$Test::Mock::Wrapped::VERSION = '0.15';
+$Test::Mock::Wrapped::VERSION = '0.16';
 use strict;
 use warnings;
 use Carp;
